@@ -1,6 +1,7 @@
-<?
+<?php
 //    MyDMS. Document Management System
 //    Copyright (C) 2002-2005  Markus Westphal
+//    Copyright (C) 2006 Malcolm Cowe
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -15,16 +16,17 @@
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
 //    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 function getFolder($id)
 {
 	GLOBAL $db;
-	
+
 	if (!is_numeric($id))
 		die ("invalid folderid");
 	
 	$queryStr = "SELECT * FROM tblFolders WHERE id = " . $id;
 	$resArr = $db->getResultArray($queryStr);
-		
+
 	if (is_bool($resArr) && $resArr == false)
 		return false;
 	else if (count($resArr) != 1)
@@ -34,6 +36,21 @@ function getFolder($id)
 	return new Folder($resArr["id"], $resArr["name"], $resArr["parent"], $resArr["comment"], $resArr["owner"], $resArr["inheritAccess"], $resArr["defaultAccess"], $resArr["sequence"]);
 }
 
+function getFolderPathHTML($folder, $tagAll=false) {
+	$path = $folder->getPath();
+	$txtpath = "";
+	for ($i = 0; $i < count($path); $i++) {
+		if ($i +1 < count($path)) {
+			$txtpath .= "<a href=\"../out/out.ViewFolder.php?folderid=".$path[$i]->getID()."\">".
+				$path[$i]->getName()."</a> / ";
+		}
+		else {
+			$txtpath .= ($tagAll ? "<a href=\"../out/out.ViewFolder.php?folderid=".$path[$i]->getID()."\">".
+									 $path[$i]->getName()."</a>" : $path[$i]->getName());
+		}
+	}
+	return $txtpath;
+}
 
 /**********************************************************************\
 |                            Folder-Klasse                             |
@@ -98,26 +115,55 @@ class Folder
 
 	function getParent()
 	{
-		if (!isset($this->_parentID) || ($this->_parentID == "") || ($this->_parentID == 0))
+		global $settings;
+
+		if ($this->_id == $settings->_rootFolderID || !isset($this->_parentID) || ($this->_parentID == null) || ($this->_parentID == "") || ($this->_parentID == 0)) {
 			return false;
-		
-		if (!isset($this->_parent))
+		}
+
+		if (!isset($this->_parent)) {
 			$this->_parent = getFolder($this->_parentID);
+		}
 		return $this->_parent;
 	}
 
 	function setParent($newParent)
 	{
-		GLOBAL $db;
+		global $db, $settings;
 		
+		if ($this->_id == $settings->_rootFolderID || !isset($this->_parentID) || ($this->_parentID == null) || ($this->_parentID == "") || ($this->_parentID == 0)) {
+			return false;
+		}
+
 		$queryStr = "UPDATE tblFolders SET parent = " . $newParent->getID() . " WHERE id = ". $this->_id;
 		$res = $db->getResult($queryStr);
 		if (!$res)
 			return false;
-		
 		$this->_parentID = $newParent->getID();
 		$this->_parent = $newParent;
-		
+
+		// Must also ensure that any documents in this folder tree have their
+		// folderLists updated.
+		$pathPrefix="";
+		$path = $this->getPath();
+		foreach ($path as $f) {
+			$pathPrefix .= ":".$f->getID();
+		}
+		if (strlen($pathPrefix)>1) {
+			$pathPrefix .= ":";
+		}
+
+		$queryStr = "SELECT `tblDocuments`.`id`, `tblDocuments`.`folderList` FROM `tblDocuments` WHERE `folderList` LIKE '%:".$this->_id.":%'";
+		$resArr = $db->getResultArray($queryStr);
+		if (is_bool($resArr) && $resArr == false)
+			return false;
+
+		foreach ($resArr as $row) {
+			$newPath = ereg_replace("^.*:".$this->_id.":(.*$)", $pathPrefix."\\1", $row["folderList"]);
+			$queryStr="UPDATE `tblDocuments` SET `folderList` = '".$newPath."' WHERE `tblDocuments`.`id` = '".$row["id"]."'";
+			$res = $db->getResult($queryStr);
+		}
+
 		return true;
 	}
 
@@ -275,46 +321,65 @@ class Folder
 		
 		if (!isset($this->_documents))
 		{
-			$queryStr = "SELECT * FROM tblDocuments WHERE folder = " . $this->_id . " ORDER BY sequence";
+			$queryStr = "SELECT tblDocuments.*, tblDocumentLocks.userID as lockUser ".
+				"FROM tblDocuments ".
+				"LEFT JOIN tblDocumentLocks ON tblDocuments.id=tblDocumentLocks.document ".
+				"WHERE folder = " . $this->_id . " ORDER BY sequence";
+
 			$resArr = $db->getResultArray($queryStr);
 			if (is_bool($resArr) && !$resArr)
 				return false;
 			
 			$this->_documents = array();
-			foreach ($resArr as $row)
-				array_push($this->_documents, new Document($row["id"], $row["name"], $row["comment"], $row["date"], $row["expires"], $row["owner"], $row["folder"], $row["inheritAccess"], $row["defaultAccess"], $row["locked"], $row["keywords"], $row["sequence"]));
+			foreach ($resArr as $row) {
+				array_push($this->_documents, new Document($row["id"], $row["name"], $row["comment"], $row["date"], $row["expires"], $row["owner"], $row["folder"], $row["inheritAccess"], $row["defaultAccess"], $row["lockUser"], $row["keywords"], $row["sequence"]));
+			}
 		}
 		return $this->_documents;
 	}
 
-	function addDocument($name, $comment, $expires, $owner, $keywords, $tmpFile, $orgFileName, $fileType, $mimeType, $sequence)
+	function addDocument($name, $comment, $expires, $owner, $keywords, $tmpFile, $orgFileName, $fileType, $mimeType, $sequence, $reviewers=array(), $approvers=array())
 	{
 		GLOBAL $db;
 		
 		$expires = (!$expires) ? 0 : $expires;
+
+		// Must also ensure that the document has a valid folderList.
+		$pathPrefix="";
+		$path = $this->getPath();
+		foreach ($path as $f) {
+			$pathPrefix .= ":".$f->getID();
+		}
+		if (strlen($pathPrefix)>1) {
+			$pathPrefix .= ":";
+		}
 		
-		$queryStr = "INSERT INTO tblDocuments (name, comment, date, expires, owner, folder, inheritAccess, defaultAccess, locked, keywords, sequence) VALUES ".
-					"('".$name."', '".$comment."', " . mktime().", ".$expires.", ".$owner->getID().", ".$this->_id.", 1, ".M_READ.", -1, '".$keywords."', " . $sequence . ")";
+		$queryStr = "INSERT INTO tblDocuments (name, comment, date, expires, owner, folder, folderList, inheritAccess, defaultAccess, locked, keywords, sequence) VALUES ".
+					"('".$name."', '".$comment."', " . mktime().", ".$expires.", ".$owner->getID().", ".$this->_id.",'".$pathPrefix."', 1, ".M_READ.", -1, '".$keywords."', " . $sequence . ")";
 		if (!$db->getResult($queryStr))
 			return false;
 		
 		$document = getDocument($db->getInsertID());
-		
-		$res = $document->addContent($comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType);
+		$res = $document->addContent($comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers);
 		if (is_bool($res) && !$res)
 		{
 			$queryStr = "DELETE FROM tblDocuments WHERE id = " . $document->getID();
 			$db->getResult($queryStr);
 			return false;
 		}
-		
-		return $document;
+
+		return array($document, $res);
 	}
 
 	function remove()
 	{
-		GLOBAL $db;
-		
+		global $db, $settings;
+
+		// Do not delete the root folder.
+		if ($this->_id == $settings->_rootFolderID || !isset($this->_parentID) || ($this->_parentID == null) || ($this->_parentID == "") || ($this->_parentID == 0)) {
+			return false;
+		}
+
 		//Entfernen der Unterordner und Dateien
 		$res = $this->getSubFolders();
 		if (is_bool($res) && !$res) return false;
@@ -348,35 +413,43 @@ class Folder
 	}
 
 
-	function getAccessList()
+	function getAccessList($mode = M_ANY, $op = O_EQ)
 	{
 		GLOBAL $db;
-		
+
 		if ($this->inheritsAccess())
 		{
 			$res = $this->getParent();
 			if (!$res) return false;
-			return $this->_parent->getAccessList();
+			return $this->_parent->getAccessList($mode, $op);
 		}
-		
-		if (!isset($this->_accessList))
+
+		if (!isset($this->_accessList[$mode]))
 		{
-			$queryStr = "SELECT * FROM tblACLs WHERE targetType = ".T_FOLDER." AND target = " . $this->_id . " ORDER BY targetType";
+			if ($op!=O_GTEQ && $op!=O_LTEQ && $op!=O_EQ) {
+				return false;
+			}
+			$modeStr = "";
+			if ($mode!=M_ANY) {
+				$modeStr = " AND mode".$op.$mode;
+			}
+			$queryStr = "SELECT * FROM tblACLs WHERE targetType = ".T_FOLDER.
+				" AND target = " . $this->_id .	$modeStr . " ORDER BY targetType";
 			$resArr = $db->getResultArray($queryStr);
 			if (is_bool($resArr) && !$resArr)
 				return false;
-			
-			$this->_accessList = array("groups" => array(), "users" => array());
+
+			$this->_accessList[$mode] = array("groups" => array(), "users" => array());
 			foreach ($resArr as $row)
 			{
 				if ($row["userID"] != -1)
-					array_push($this->_accessList["users"], new UserAccess($row["userID"], $row["mode"]));
+					array_push($this->_accessList[$mode]["users"], new UserAccess($row["userID"], $row["mode"]));
 				else //if ($row["groupID"] != -1)
-					array_push($this->_accessList["groups"], new GroupAccess($row["groupID"], $row["mode"]));
+					array_push($this->_accessList[$mode]["groups"], new GroupAccess($row["groupID"], $row["mode"]));
 			}
 		}
-		
-		return $this->_accessList;
+
+		return $this->_accessList[$mode];
 	}
 
 	function clearAccessList()
@@ -516,6 +589,34 @@ class Folder
 		return $this->getDefaultAccess();
 	}
 
+	function getGroupAccessMode($group)
+	{
+		GLOBAL $settings;
+		
+		$highestPrivileged = M_NONE;
+		$foundInACL = false;
+		$accessList = $this->getAccessList();
+		if (!$accessList)
+			return false;
+			
+		foreach ($accessList["groups"] as $groupAccess)
+		{
+			if ($groupAccess->getGroupID() == $group->getID())
+			{
+				$foundInACL = true;
+				if ($groupAccess->getMode() > $highestPrivileged)
+					$highestPrivileged = $groupAccess->getMode();
+				if ($highestPrivileged == M_ALL) //hher geht's nicht -> wir knnen uns die arbeit schenken
+					return $highestPrivileged;
+			}
+		}
+		if ($foundInACL)
+			return $highestPrivileged;
+		
+		//Standard-Berechtigung verwenden
+		return $this->getDefaultAccess();
+	}
+
 	function getNotifyList()
 	{
 		if (!isset($this->_notifyList))
@@ -566,6 +667,108 @@ class Folder
 		unset($this->_notifyList);
 		return true;
 	}
+
+	function getApproversList() {
+		GLOBAL $db, $settings;
+
+		if (!isset($this->_approversList)) {
+			$this->_approversList = array("groups" => array(), "users" => array());
+			$userIDs = "";
+			$groupIDs = "";
+			$defAccess  = $this->getDefaultAccess();
+
+			if ($defAccess<M_READ) {
+				// Get the list of all users and groups that are listed in the ACL as
+				// having write access to the folder.
+				$tmpList = $this->getAccessList(M_READ, O_GTEQ);
+			}
+			else {
+				// Get the list of all users and groups that DO NOT have write access
+				// to the folder.
+				$tmpList = $this->getAccessList(M_NONE, O_LTEQ);
+			}
+			foreach ($tmpList["groups"] as $group) {
+				$groupIDs .= (strlen($groupIDs)==0 ? "" : ", ") . $group->getGroupID();
+			}
+			foreach ($tmpList["users"] as $user) {
+				if ($user->getUserID()!=$settings->_guestID) {
+					$userIDs .= (strlen($userIDs)==0 ? "" : ", ") . $user->getUserID();
+				}
+			}
+
+			// Construct a query against the users table to identify those users
+			// that have write access to this folder, either directly through an
+			// ACL entry, by virtue of ownership or by having administrative rights
+			// on the database.
+			$queryStr="";
+			if ($defAccess < M_READ) {
+				if (strlen($groupIDs)>0) {
+					$queryStr = "(SELECT `tblUsers`.* FROM `tblUsers` ".
+						"LEFT JOIN `tblGroupMembers` ON `tblGroupMembers`.`userID`=`tblUsers`.`id` ".
+						"WHERE `tblGroupMembers`.`groupID` IN (". $groupIDs .") ".
+						"AND `tblUsers`.`id` !='".$settings->_guestID."')";
+				}
+				$queryStr .= (strlen($queryStr)==0 ? "" : " UNION ").
+					"(SELECT `tblUsers`.* FROM `tblUsers` ".
+					"WHERE (`tblUsers`.`id` !='".$settings->_guestID."') ".
+					"AND ((`tblUsers`.`id` = ". $this->_ownerID . ") ".
+					"OR (`tblUsers`.`isAdmin` = 1)".
+					(strlen($userIDs) == 0 ? "" : " OR (`tblUsers`.`id` IN (". $userIDs ."))").
+					")) ORDER BY `login`";
+			}
+			else {
+				if (strlen($groupIDs)>0) {
+					$queryStr = "(SELECT `tblUsers`.* FROM `tblUsers` ".
+						"LEFT JOIN `tblGroupMembers` ON `tblGroupMembers`.`userID`=`tblUsers`.`id` ".
+						"WHERE `tblGroupMembers`.`groupID` NOT IN (". $groupIDs .")".
+						"AND `tblUsers`.`id` != '".$settings->_guestID."' ".
+						(strlen($userIDs) == 0 ? ")" : " AND (`tblUsers`.`id` NOT IN (". $userIDs .")))");
+				}
+				$queryStr .= (strlen($queryStr)==0 ? "" : " UNION ").
+					"(SELECT `tblUsers`.* FROM `tblUsers` ".
+					"WHERE (`tblUsers`.`id` = ". $this->_ownerID . ") ".
+					"OR (`tblUsers`.`isAdmin` = 1))".
+					"UNION ".
+					"(SELECT `tblUsers`.* FROM `tblUsers` ".
+					"WHERE `tblUsers`.`id` != '".$settings->_guestID."' ".
+					(strlen($userIDs) == 0 ? ")" : " AND (`tblUsers`.`id` NOT IN (". $userIDs .")))").
+					" ORDER BY `login`";
+			}
+			$resArr = $db->getResultArray($queryStr);
+			if (!is_bool($resArr)) {
+				foreach ($resArr as $row) {
+					$this->_approversList["users"][] = new User($row["id"], $row["login"], $row["pwd"], $row["fullName"], $row["email"], $row["language"], $row["theme"], $row["comment"], $row["isAdmin"]);
+				}
+			}
+
+			// Assemble the list of groups that have write access to the folder.
+			$queryStr="";
+			if ($defAccess < M_READ) {
+				if (strlen($groupIDs)>0) {
+					$queryStr = "SELECT `tblGroups`.* FROM `tblGroups` ".
+						"WHERE `tblGroups`.`id` IN (". $groupIDs .")";
+				}
+			}
+			else {
+				if (strlen($groupIDs)>0) {
+					$queryStr = "SELECT `tblGroups`.* FROM `tblGroups` ".
+						"WHERE `tblGroups`.`id` NOT IN (". $groupIDs .")";
+				}
+				else {
+					$queryStr = "SELECT `tblGroups`.* FROM `tblGroups`";
+				}
+			}
+			if (strlen($queryStr)>0) {
+				$resArr = $db->getResultArray($queryStr);
+				if (!is_bool($resArr)) {
+					foreach ($resArr as $row) {
+						$this->_approversList["groups"][] = new Group($row["id"], $row["name"], $row["comment"]);
+					}
+				}
+			}
+		}
+		return $this->_approversList;
+	}
 }
 
 ?>
