@@ -1,6 +1,7 @@
-<?
+<?php
 //    MyDMS. Document Management System
 //    Copyright (C) 2002-2005  Markus Westphal
+//    Copyright (C) 2006 Malcolm Cowe
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -57,7 +58,7 @@ function printHTMLHead($title)
 function printHTMLFoot()
 {
 	global $theme;
-	
+
 	if ( is_file("../themes/$theme/HTMLFoot.html" ) )
 	{
 		include("../themes/$theme/HTMLFoot.html");
@@ -135,6 +136,7 @@ function printTitleBar($folder)
 	
 	$options=array();
 	$options[getMLText("content")]=$settings->_httpRoot . "out/out.ViewFolder.php?folderid=" . $folder->getID();
+	$options[getMLText("actions")]=$settings->_httpRoot . "out/out.ActionSummary.php";
 	$options[getMLText("search")]=$settings->_httpRoot . "out/out.SearchForm.php?folderid=" . $folder->getID();
 	
 	if ($user->getID() != $settings->_guestID)
@@ -263,7 +265,7 @@ function printFolderPageEnd($folder)
 {
 
 	GLOBAL $user, $theme;
-	
+
 	$title = getMLText("edit_folder");
 	$options=array();
 	$accessMode = $folder->getAccessMode($user);
@@ -331,6 +333,9 @@ function printDocumentPageEnd($document)
 	$title = getMLText("edit_document");
 	$options=array();
 	$accessMode = $document->getAccessMode($user);
+
+	$options[getMLText("overview")]	= "out.ViewDocument" . $docid;
+
 	if ($accessMode >= M_READWRITE)
 	{
 	  if (!$document->isLocked())
@@ -443,10 +448,10 @@ function printDocumentChooser($formName) {
 	<script language="JavaScript">
 	var openDlg;
 	function chooseDoc() {
-		openDlg = open("out.DocumentChooser.php?folderid=<?=$settings->_rootFolderID?>&form=<?=urlencode($formName)?>", "openDlg", "width=300,height=450,scrollbars=yes,resizable=yes,status=yes");
+		openDlg = open("../out/out.DocumentChooser.php?folderid=<?php echo $settings->_rootFolderID?>&form=<?php echo urlencode($formName)?>", "openDlg", "width=300,height=450,scrollbars=yes,resizable=yes,status=yes");
 	}
 	</script>
-	<?
+	<?php
 	print "<input type=\"Hidden\" name=\"docid\">";
 	print "<input disabled name=\"docname\">";
 	print "&nbsp;&nbsp;<input type=\"Button\" value=\"Open...\" onclick=\"chooseDoc();\">";
@@ -459,10 +464,10 @@ function printFolderChooser($formName, $accessMode, $exclude = -1, $default = fa
 	<script language="JavaScript">
 	var openDlg;
 	function chooseDoc() {
-		openDlg = open("out.FolderChooser.php?form=<?=$formName?>&mode=<?=$accessMode?>&exclude=<?=$exclude?>&folderid=<?=$settings->_rootFolderID?>", "openDlg", "width=300,height=450,scrollbars=yes,resizable=yes,status=yes");
+		openDlg = open("out.FolderChooser.php?form=<?php echo $formName?>&mode=<?php echo $accessMode?>&exclude=<?php echo $exclude?>&folderid=<?php echo $settings->_rootFolderID?>", "openDlg", "width=300,height=450,scrollbars=yes,resizable=yes,status=yes");
 	}
 	</script>
-	<?
+	<?php
 	print "<input type=\"Hidden\" name=\"targetid\" value=\"". (($default) ? $default->getID() : "") ."\">";
 	print "<input disabled name=\"targetname\" value=\"". (($default) ? $default->getName() : "") ."\">";
 	print "&nbsp;&nbsp;<input type=\"Button\" value=\"Open...\" onclick=\"chooseDoc();\">";
