@@ -1,6 +1,7 @@
-<?
+<?php
 //    MyDMS. Document Management System
 //    Copyright (C) 2002-2005  Markus Westphal
+//    Copyright (C) 2006 Malcolm Cowe
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -15,7 +16,10 @@
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
 //    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-header("Location: out/out.ViewFolder.php");
+
+include("inc/inc.Settings.php");
+
+header("Location: ". (isset($settings->_siteDefaultPage) && strlen($settings->_siteDefaultPage)>0 ? $settings->_siteDefaultPage : "out/out.ViewFolder.php"));
 ?>
 <html>
 <head>
